@@ -52,7 +52,7 @@ class CustomHTTPAdapter(requests.adapters.HTTPAdapter):
 class HTTPClient(requests.Session):
     """A class to make HTTP requests using the CustomHTTPAdapter."""
 
-    def __init__(self, auth: AuthBase):
+    def __init__(self, auth: AuthBase = None):
         super().__init__()
         self.auth: AuthBase = auth
         adapter = CustomHTTPAdapter()
@@ -124,7 +124,7 @@ class Buckets(ApiClient):
         bucket_args = BucketArgs(**bucket_payload)
         return Bucket(bucket_args, buckets_router=self)
 
-    def create(self, description: str, schemaless: bool) -> "Bucket":
+    def create(self, description: str, schemaless: bool = False) -> "Bucket":
         data = {"description": description, "schemaless": schemaless}
         url = self.url_for("/buckets")
         response = self.client.post(url, json=data)
@@ -140,12 +140,12 @@ class Buckets(ApiClient):
             self._bucket_from_payload(payload) for payload in bucket_payload
         ]
 
-    def get(self, bucket_ref: str) -> "Bucket":
+    def get(self, bucket: str) -> "Bucket":
         """Return a Bucket.
         Args:
-            bucket_ref: the name or the uuid of the bucket.
+            bucket: the name or the uuid of the bucket.
         """
-        endpoint = f"/buckets/{bucket_ref}"
+        endpoint = f"/buckets/{bucket}"
         url = self.url_for(endpoint)
         response = self.client.get(url)
         bucket_payload = response.json()
@@ -177,15 +177,33 @@ class Buckets(ApiClient):
         response = self.client.post(self.url_for("/buckets/query"), json=data)
         return response.json()
 
-    def push_data(self, bucket_ref: str, rows: List[Dict[str, Any]]):
+    def push_data(self, bucket: str, rows: List[Dict[str, Any]]):
         data = {"data": rows}
         response = self.client.post(
-            self.url_for(f"/buckets/{bucket_ref}/data"), json=data
+            self.url_for(f"/buckets/{bucket}/data"), json=data
         )
         return response.json()
 
-    def get_data(self, bucket_ref: str) -> List[Dict[str, Any]]:
-        response = self.client.get(self.url_for(f"/buckets/{bucket_ref}/data"))
+    def get_data(self, bucket: str) -> List[Dict[str, Any]]:
+        response = self.client.get(self.url_for(f"/buckets/{bucket}/data"))
+        return response.json()
+
+
+class ApiTokens(ApiClient):
+    def create(self, description: str = None):
+        data = {"description": description}
+        url = self.url_for("/api_tokens")
+        response = self.client.post(url, json=data)
+        return response.json()
+
+    def list(self):
+        url = self.url_for("/api_tokens")
+        response = self.client.get(url)
+        return response.json()
+
+    def delete(self, token_uuid: str):
+        url = self.url_for(f"/api_tokens/{token_uuid}")
+        response = self.client.delete(url)
         return response.json()
 
 
@@ -211,6 +229,9 @@ class Bucket:
         self.schemaless = bucket_payload.schemaless
         self._buckets_router = buckets_router
 
+    def __repr__(self):
+        return f"Bucket<{self.name}>"
+
     def delete(self) -> Dict[str, Any]:
         return self._buckets_router.delete(self.uuid)
 
@@ -244,20 +265,29 @@ class AdacordApi:
     def Buckets(self) -> Buckets:
         return Buckets(self.client)
 
-    def Bucket(self, bucket_uuid: str) -> Bucket:
-        return self.Buckets.get(bucket_uuid)
+    @property
+    def ApiTokens(self) -> Buckets:
+        return ApiTokens(self.client)
+
+    def Bucket(self, bucket: str) -> Bucket:
+        return self.Buckets.get(bucket)
 
     @classmethod
-    def Client(cls, token: str) -> "AdacordApi":
-        client = HTTPClient.with_token(token)
+    def Client(cls, with_auth: bool = True, token: str = None) -> "AdacordApi":
+        if token:
+            client = HTTPClient.with_token(token)
+        elif with_auth:
+            client = None
+        else:
+            client = HTTPClient()
         return cls(client)
 
     def create_bucket(self, description: str, schemaless: bool) -> Bucket:
         return self.Buckets.create(description, schemaless)
 
-    def get_bucket(self, bucket_uuid: str) -> Bucket:
-        return self.Buckets.get(bucket_uuid)
+    def get_bucket(self, bucket: str) -> Bucket:
+        return self.Buckets.get(bucket)
 
 
-def create_api() -> AdacordApi:
-    return AdacordApi.Client(get_token())
+def create_api(with_auth: bool = True) -> AdacordApi:
+    return AdacordApi.Client(with_auth=with_auth)
